@@ -1,14 +1,15 @@
 package Dancer::Cookie;
 our $AUTHORITY = 'cpan:SUKRIA';
 #ABSTRACT: class representing cookies
-$Dancer::Cookie::VERSION = '1.3512';
+$Dancer::Cookie::VERSION = '1.3520';
 use strict;
 use warnings;
 
+use Carp;
 use URI::Escape;
 
 use base 'Dancer::Object';
-__PACKAGE__->attributes( qw/name expires domain path secure http_only/ );
+__PACKAGE__->attributes( qw/name expires domain path same_site secure http_only/ );
 
 sub init {
     my ($self, %args) = @_;
@@ -23,6 +24,19 @@ sub init {
         $self->expires($time);
     }
     $self->path('/') unless defined $self->path;
+
+    # If we have a same_site attribute, ensure it's sane:
+    if (my $same_site = $self->same_site) {
+        if ($same_site !~ m{^(Strict|Lax|None)$}i) {
+            Carp::croak(
+                "Invalid same_site value '$same_site'"
+                . " - must be 'Strict', 'Lax' or 'None', see RFC6265bis"
+            );
+        } else {
+            # Normalise case
+            $self->same_site(ucfirst lc $same_site);
+        }
+    }
 }
 
 sub to_header {
@@ -36,10 +50,11 @@ sub to_header {
     $name =~ s/[=,; \t\r\n\013\014]//mg;
 
     my @headers = $name . '=' . $value;
-    push @headers, "path=" . $self->path        if $self->path;
-    push @headers, "expires=" . $self->expires  if $self->expires;
-    push @headers, "domain=" . $self->domain    if $self->domain;
-    push @headers, "Secure"                     if $self->secure;
+    push @headers, "path="     . $self->path      if $self->path;
+    push @headers, "expires="  . $self->expires   if $self->expires;
+    push @headers, "domain="   . $self->domain    if $self->domain;
+    push @headers, "Secure"                       if $self->secure;
+    push @headers, "SameSite=" . $self->same_site if $self->same_site;
     push @headers, 'HttpOnly'                   unless $no_httponly;
 
     return join '; ', @headers;
@@ -132,7 +147,7 @@ Dancer::Cookie - class representing cookies
 
 =head1 VERSION
 
-version 1.3512
+version 1.3520
 
 =head1 SYNOPSIS
 
